.nbtutor-buttons button {
    padding: 0px;
    height: 22px;
    line-height: 2px;
    font-size: x-small;
}

.nbtutor-legend {
    margin-left: 10px;
}

/*This should come last to overwrite previous class displays*/
.nbtutor-hidden {
    display: none;
}

