
table.nbtutor-active {
    background: steelblue;
}

.nbtutor-hover,
table.nbtutor-hover {
    background: brown;
}

.jtk-hover circle,
.jtk-hover path {
    stroke: brown;
}

path.jtk-hover,
.jtk-hover circle {
    fill: brown;
}

.nbtutor-prev-line {
    color: green;
}

.nbtutor-current-line {
    color: blue;
}

.nbtutor-next-line {
    color: brown;
}
