.nbtutor-stack,
.nbtutor-heap,
.nbtutor-timeline
{
    padding: 10px;
}

.nbtutor-canvas {
    font-family: monospace;
}

.nbtutor-canvas table {
    background: lightgrey;
}

.nbtutor-stack th {
    padding: 5px;
    font-style: italic;
}

.nbtutor-stack .nbtutor-frame {
    margin-bottom: 20px;
}

.nbtutor-stack .nbtutor-var-name {
    padding-left: 5px;
    padding-right: 5px;
    padding-bottom: 3px;
    text-align: right;
}

.nbtutor-stack .nbtutor-anchor-from {
    width: 21px;
    border-left: 1px solid black;
    border-bottom: 1px solid black;
}

.nbtutor-stack .nbtutor-anchor-from div {
    padding: 10px 5px 10px 5px;
}

.nbtutor-stack .nbtutor-anchor-from div:empty {
    padding: 10px 0px 10px 10px;
    margin-right: 10px;
}

.nbtutor-heap .nbtutor-var-object {
    margin-bottom: 10px;
    white-space: nowrap;
    text-align: right;
}

.nbtutor-heap .nbtutor-var-type {
    font-size: x-small;
    margin-right: 3px;
}

.nbtutor-heap .nbtutor-var-value {
    padding: 5px;
    border-radius: 5px;
    border: 1px solid black;
    text-align: center;
}

.nbtutor-heap .nbtutor-var-index{
    padding-left: 3px;
    text-align: left;
    font-size: x-small;
}

.nbtutor-heap .nbtutor-seq-array td,
.nbtutor-heap .nbtutor-seq-set td,
.nbtutor-heap .nbtutor-seq-tuple td,
.nbtutor-heap .nbtutor-seq-list td {
    border-left: 1px solid black;
}

.nbtutor-heap .nbtutor-seq-array tr:last-child,
.nbtutor-heap .nbtutor-seq-set tr:last-child,
.nbtutor-heap .nbtutor-seq-tuple tr:last-child,
.nbtutor-heap .nbtutor-seq-list tr:last-child {
    border-bottom: 1px solid black;
}

.nbtutor-heap .nbtutor-seq-array td,
.nbtutor-heap .nbtutor-seq-set td,
.nbtutor-heap .nbtutor-seq-tuple td {
    border-right: 1px solid black;
}

.nbtutor-heap .nbtutor-seq-array tr:first-child,
.nbtutor-heap .nbtutor-seq-set tr:first-child,
.nbtutor-heap .nbtutor-seq-tuple tr:first-child {
    border-top: 1px solid black;
}

.nbtutor-heap .nbtutor-seq-key-value tr {
    border-bottom: 1px solid black;
}

.nbtutor-heap .nbtutor-seq-key-value tr td:first-child {
    border-right: 1px solid black;
}

.nbtutor-heap .nbtutor-anchor-from div {
    padding: 5px 10px 5px 10px;
}

.nbtutor-heap .nbtutor-anchor-from div:empty {
    margin-top: 10px;
}

.nbtutor-timeline table {
    border-collapse: collapse;
}

.nbtutor-timeline td {
    padding: 5px;
    text-align: center;
    width: 20px;
}

.nbtutor-timeline th:first-child {
    font-style: italic;
    padding-bottom: 5px;
    white-space: nowrap;
}

.nbtutor-timeline tr > td:first-child,
.nbtutor-timeline tr:last-child > th:first-child {
    text-align: left;
    border-right: 1px solid black;
}

.nbtutor-timeline tr:last-child > th {
    padding: 5px;
    min-width: 36px;
    border-bottom: 1px solid black;
}
